@@ -1,10 +1,9 @@
 package Form::Factory;
-BEGIN {
-  $Form::Factory::VERSION = '0.020';
-}
+$Form::Factory::VERSION = '0.021';
 use Moose;
 
 use Carp ();
+use Class::Load;
 
 =head1 NAME
 
@@ -12,7 +11,7 @@ Form::Factory - a general-purpose form handling API
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -199,14 +198,14 @@ sub _load_class_from_name {
     for my $type ($given_type, $custom_type) {
         my $class_name = _class_name_from_name($type, $name);
 
-        if (not eval { Class::MOP::load_class($class_name) }) {
+        if (not eval { Class::Load::load_class($class_name) }) {
             $ERROR ||= $@ if $@;
             $ERROR ||= "failed to load $type class named $name";;
         }
         elsif ($type eq $custom_type) {
             $class_name = $class_name->register_implementation;
 
-            if (eval { Class::MOP::load_class($class_name) }) {
+            if (eval { Class::Load::load_class($class_name) }) {
                 return $class_name;
             }
             else {
@@ -270,4 +269,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
