@@ -1,7 +1,5 @@
 package Form::Factory::Control::Role::Labeled;
-BEGIN {
-  $Form::Factory::Control::Role::Labeled::VERSION = '0.020';
-}
+$Form::Factory::Control::Role::Labeled::VERSION = '0.021';
 use Moose::Role;
 
 =head1 NAME
@@ -10,7 +8,7 @@ Form::Factory::Control::Role::Labeled - labeled controls
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 DESCRIPTION
 
@@ -29,6 +27,7 @@ has label => (
     isa       => 'Str',
     required  => 1,
     builder   => '_build_label',
+    lazy      => 1,
 );
 
 sub _build_label {
@@ -52,4 +51,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
