@@ -1,7 +1,5 @@
 package Form::Factory::Feature::Control::FillOnAssignment;
-BEGIN {
-  $Form::Factory::Feature::Control::FillOnAssignment::VERSION = '0.020';
-}
+$Form::Factory::Feature::Control::FillOnAssignment::VERSION = '0.021';
 use Moose;
 
 with qw(
@@ -19,7 +17,7 @@ Form::Factory::Feature::Control::FillOnAssignment - Control gets the value of th
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -61,7 +59,7 @@ This names the slot that will be filled with the value. This must be either C<va
 use Moose::Util::TypeConstraints;
 
 enum 'Form::Factory::Feature::Control::FillOnAssignment::Slot'
-    => qw( value default_value );
+    => [qw( value default_value )];
 
 no Moose::Util::TypeConstraints;
 
@@ -141,4 +139,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
