@@ -1,10 +1,9 @@
 package Form::Factory::Interface;
-BEGIN {
-  $Form::Factory::Interface::VERSION = '0.020';
-}
+$Form::Factory::Interface::VERSION = '0.021';
 use Moose::Role;
 
 use Carp ();
+use Class::Load;
 use Form::Factory::Stasher::Memory;
 
 requires qw( render_control consume_control );
@@ -15,7 +14,7 @@ Form::Factory::Interface - Role for form interface implementations
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -78,7 +77,7 @@ Given the name of an action class, it initializes the class for use with this in
 sub new_action {
     my ($self, $class_name, $args) = @_;
 
-    Class::MOP::load_class($class_name)
+    Class::Load::load_class($class_name)
         or Carp::croak("cannot load $class_name: $@");
 
     return $class_name->new( %$args, form_interface => $self );
@@ -174,4 +173,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
