@@ -1,11 +1,9 @@
 package Form::Factory::Message;
-BEGIN {
-  $Form::Factory::Message::VERSION = '0.020';
-}
+$Form::Factory::Message::VERSION = '0.021';
 use Moose;
 
 use Moose::Util::TypeConstraints;
-enum 'Form::Factory::Message::Type' => qw( info warning error );
+enum 'Form::Factory::Message::Type' => [qw( info warning error )];
 no Moose::Util::TypeConstraints;
 
 =head1 NAME
@@ -14,7 +12,7 @@ Form::Factory::Message - Handy class for encapsulating messages
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -103,4 +101,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
