@@ -1,7 +1,5 @@
 package Form::Factory::Processor;
-BEGIN {
-  $Form::Factory::Processor::VERSION = '0.020';
-}
+$Form::Factory::Processor::VERSION = '0.021';
 use Moose;
 use Moose::Exporter;
 
@@ -26,7 +24,7 @@ Form::Factory::Processor - Moos-ish helper for action classes
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -98,9 +96,11 @@ sub init_meta {
 
     Moose->init_meta(%options);
 
-    my $meta = Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class       => $options{for_class},
-        metaclass_roles => [ 'Form::Factory::Action::Meta::Class' ],
+    my $meta = Moose::Util::MetaRole::apply_metaroles(
+        for             => $options{for_class},
+        class_metaroles => {
+            class => [ 'Form::Factory::Action::Meta::Class' ],
+        },
     );
 
     Moose::Util::apply_all_roles(
@@ -318,4 +318,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
